==> AnnBuilder_1.3.3.tar.gz: AnnBuilder/R/writeManPage.R <==
# This function writes all the elements other than rda files required
# for a data package
writeAccessory <- function(pkgName, pkgPath, organism, version,
                         author = list(author = "who",
                         maintainer = "who@email.net"),
                         dataSrc = "various public data repositories",
                         license = "LGPL"){
    # Write to DESCRIPTION
    writeDescription(pkgName, pkgPath, version, author, dataSrc, license)
    # Write Rd files for all the rda files that already exist in data
    for(i in getAllRdaName(pkgName, pkgPath)){
        writeManPage(pkgName, pkgPath, i, organism,
                     src = get(i, AnnInfo)$src)
    }
    # Write a function that displays data information when called
    # using pkgName() and the man page for the function
    writeFun (pkgPath, pkgName, organism = organism)
    writeMan4Fun(pkgName, pkgPath, organism)
    # Write .First.lib
    writeZZZ(pkgPath, pkgName)
    # Put the pretty print function for QC data and man page in
#    putPrettyPrint(pkgName, pkgPath)
}

# Functions that write the documentation files for a data package.
#
# Copyright 2002, J. Zhang, all rights reserved.
#

writeManPage <- function(pkgName, pkgPath, manName, organism = "human",
                         src = "ll", isEnv = TRUE){

    path <- file.path(pkgPath, pkgName, "man")
    filename <- file.path(path, paste(pkgName, formatName(manName),
                                    ".Rd", sep = ""))
    if(is.na(src)){
        srcBuild <- "N/A"
    }else{
        if(toupper(organism) == "YEAST"){
            srcBuild <- getBuild4Yeast(src, manName)
        }else{
            srcBuild <- getSrcBuiltNRef(src, organism)
        }
    }
    write(paste("\\name{", paste(pkgName, manName, sep = ""), "}\n",
                "\\alias{", paste(pkgName, manName, sep = ""), "}\n",
                "\\title{", "An annotation data file for ", manName,
                " in the ", pkgName, " package}\n",
                "\\description{\n", get(manName, AnnInfo)$long, "\n}\n",
                srcBuild, getExample(pkgName, manName, isEnv),
                "\\keyword{datasets}\n", sep = ""), filename)
}

getExample <- function(pkgName, manName, isEnv = TRUE){
    if(isEnv){
        return(paste("\\examples{\n", paste(paste("xx <- ls(env = ",
                           paste(pkgName, formatName(manName), sep = ""),
                           ")", sep = ""), "if(length(xx) > 0){",
                                            paste("get(xx[1], env = ",
                           paste(pkgName, formatName(manName), ")",
                                 sep = ""), "}", sep = ""), sep = "\n"),
                           "\n}\n", sep = ""))
    }else{
        return(paste("\\examples{\n",
               paste(pkgName, manName, sep = ""), "\n}\n", sep = ""))
    }
}

getSrcBuiltNRef <- function(src, organism){
    switch(toupper(src),
           "LL" = dataSource <- "LocusLink",
           "UG" = dataSource <- "UniGene",
           "KEGG" = dataSource <- "KEGG",
           "GO" = dataSource <- "Gene Ontology",
           "GP" = dataSource <- "Human Genome Project",
           "YG" = dataSrurce <- "Yeast Genome Project",
           "HG" = dataSource <- "HomoloGene",
           dataSource <- src)

    if(src == ""){
        return(paste("\\details{\n",
               paste(paste("Package built:", date())), "\n}\n", sep = ""))
    }else{
        return(paste("\\details{\n", paste("Mappings were based on data ",
                                           "provided by ", dataSource,
                                           "\n\n", sep = ""),
                     paste(paste("Source data built:",
                                 getSrcNBuilt(src, organism), "\n",
                                 paste("Package built:", date()),
                                 sep = "")), "\n}\n",
                     "\\references{\n", paste("\\url{", getSrcUrl(src), "}",
                                              sep = ""), "\n}\n", sep = ""))
    }
}

# This function writes the man page for the function that displays
# data information when invoked by typing pkgName()
writeMan4Fun <- function(pkgName, pkgPath, organism = "human", QCList){
    fileName <- file.path(pkgPath, pkgName, "man",
                          paste(pkgName, ".Rd", sep = ""))
    dSrc <- getDSrc(organism)
    item <- getSrcNBuilt(dSrc, organism)
    item <- paste(item, sep = "\n")
    write(paste("\\name{", pkgName, "}\n",
                "\\alias{", pkgName, "}\n",
                "\\title{",
                "Genomic Annotation data package built with AnnBuilder}\n",
                "\\description{\nThe package is built using a ",
                "downloadable R package - AnnBuilder (download and build ",
                "your own) from www.bioconductor.org using the ",
                "following public data sources:\n", item,
                "\n\nThe function ", pkgName, "() provides ",
                "information about the binary data files}\n",
                "\\keyword{datasets}\n", sep = ""), fileName)

}

escapeLatexChr <- function(item){
    item <- gsub("_", "\\\\_", item)
    item <- gsub("#", "\\\\#", item)
    item <- gsub("&", "\\\\&", item)
    item <- gsub("%", "\\\\%", item)
    item <- gsub("{", "\\\\{", item)
    item <- gsub("}", "\\\\}", item)
    return(item)
}

getSrcNBuilt <- function(dSrc, organism){
    items <- ""
    for(i in dSrc){
        switch(toupper(i),
               "LL" = toAdd <- paste("LocusLink",
                                      getUrlNBuilt("LL", organism)),
               "GP" = toAdd <- paste("Human Genome Project",
                                 getUrlNBuilt("GP", organism)),
               "UG" = toAdd <- paste("UniGene",
                                      getUrlNBuilt("UG", organism)),
               "GO" = toAdd <- paste("Gene Ontology Consortium",
                                      getUrlNBuilt("GO", organism)),
               "KEGG" = toAdd <- paste("KEGG",
                                      getUrlNBuilt("KEGG", organism)),
               "YG" = toAdd <- paste("Yeast Genome",
                                      getUrlNBuilt("YG", organism)),
               "HG" = toAdd <- paste("Homology",
                                      getUrlNBuilt("HG"), organism),
               warning(paste("Source", i, "is not a valid name!")))
        items <- paste(items, "\n", toAdd, sep = "")
    }
    return(items)
}

getUrlNBuilt <- function(src, organism){
    paste("built: ", escapeLatexChr(getSrcBuilt(src, organism)), ".",
          "\\url{", escapeLatexChr(getSrcUrl(src, organism)), "}.", sep = "")
}

#getItem <- function(name, content){
#    paste("\\item{", name, "}{",content, "}", sep = "")
#}

formatName <- function (toFormat){
    gsub("*(_)*", "", toFormat)
}

writeREADME <- function(pkgPath, pkgName, urls){

    OPENING <- paste("The binary data files in this package were constructed",
                     "using data from the following sources identified",
                     "by their URLs:")
    CLOSING <- paste("We highly appreciate their efforts of making",
                     "the data available publically")


    fileName <- file.path(pkgPath, pkgName, "README")

    write(OPENING, file = fileName, append = FALSE)
    for(i in urls)
        write(i, file = fileName, append = TRUE)
    write(CLOSING, file = fileName, append = TRUE)
}

#writeIndex <- function(path, pkgname){
#    indexPath <- file.path(path, pkgname)
#    system(paste("cd", indexPath))
#    system("R CMD Rdindex man >INDEX")
#    system(paste("cd", getwd()))
#}

writeDescription <- function(pkgName, pkgPath, version, author,
                             dataSrc = "various public data repositories",
                             license = "LGPL"){

    path <- file.path(pkgPath, pkgName)
    fileName <- file.path(path, "DESCRIPTION")
    if(file.exists(fileName)){
        unlink(fileName)
    }

    write(paste("Package:", pkgName,
                "\nTitle: A data package containing",
                "annotation data for", pkgName,
                "\nVersion:", version,
                "\nCreated:", date(),
                "\nAuthor:", author[["author"]],
                "\nDescription: Annotation data file for",
                pkgName, "assembled using data\n   from",
                dataSrc,
                "\nMaintainer:", author[["author"]], "<",
                author[["maintainer"]], ">",
                "\nLicense:", license, "\n"), file = fileName, append = FALSE)
}


getDSrc <- function(organism){
    switch(tolower(organism),
           "human" = ,
           "rat" = ,
           "mouse" = return(c("LL", "GO", "KEGG", "GP", "UG")),
           "yeast" = return(c("KEGG", "GO", "YG")),
           "kegg" = return("KEGG"),
           "go" = return("GO"),
           "hg" = return("HG"),
           stop(paste("Organism", organism, "not supported!")))
}

# This function searches the package to be built for names of the rda
# files already created
getAllRdaName <- function(pkgName, pkgPath){
    rdaNames <- gsub(paste("(^", pkgName, "|.rda$)", sep = ""), "",
                     list.files(file.path(pkgPath, pkgName, "data")))
    return(rdaNames[!is.element(rdaNames, c("QC", "print.ABQCList"))])
}

writeFun <- function (pkgPath, pkgName, organism = "human"){
    fileName <- file.path(pkgPath, pkgName, "R",
                          paste(pkgName, ".R", sep = ""))

    toWrite <- paste(pkgName, " <- function(){\n",
                     "load(file.path(.path.package(\"", pkgName, "\"), ",
                     "\"data\", \"", paste(pkgName, "QC.rda", sep = ""),
                     "\"))\ncat(", paste(pkgName, "QC", sep = ""),
                     ")}", sep = "")

   write(toWrite, file = fileName)
}

writeZZZ <- function(pkgPath, pkgName){
    fileName <- file.path(pkgPath, pkgName, "R", "zzz.R")
    copySubstitute(file.path(.path.package("AnnBuilder"), "scripts",
                             "dataPkgLoad.R"), fileName,
                   list(PACKAGE = pkgName))
}

#putPrettyPrint <- function(pkgName, pkgPath){
#    path <- file.path(.path.package("AnnBuilder"))
#    dump("print.ABQCList", file = file.path(pkgPath, pkgName, "R",
#                           "print.ABQCList.R"))
#    manPage <- readLines(file.path(path, "data", "print.ABQCList.Rd"))
#    write(manPage, file = file.path(pkgPath, pkgName, "man",
#    "print.ABQCList.Rd"))
#}


#getText4Desc <- function(pkgName, manName){
    # This is not used but still kept here
#    description <- paste("This is an R rda file (a external ",
#                         "representation of R objects that canbe ",
#                         "read back from at a later date by using ",
#                         "the function `load' (or `data' in some ",
#                         "cases)) that contains an R environment ",
#                         "object with key-value paris. For a ",
#                         "given key, the value is a vector with a ",
#                         "single or multiple elements depending ",
#                             "on whether the key can be mapped to ",
#                         "only one or a group of values",
#                         "\n\nAll the funcitons that can be ",
#                         "applied to an R environment is ",
#                         "applicable to the data file. For ",
#                         "example, ls(", paste(pkgName, manName,
#                                               sep = ""), ") ",
#                         "returns a vector containing all the ",
#                             "keys and get(", "keyvalue", "env = ",
#                         paste(pkgName, manName, sep = ""),
#                         " returns a vector containg the ",
#                         "value(s) corresponding to the key ",
#                         "(keyvalue). multiget(c(\"key1\", ",
#                         "\"key2\", ..., \"keyX\"), env = ",
#                         paste(pkgName, manName, sep = ""),
#                             ") returns a list with the ",
#                         "corresponding values as elements.", sep = "")
#    return()
#}

writeMan4QC <- function(pkgName, pkgPath){

    path <- file.path(pkgPath, pkgName, "man")
    filename <- file.path(pkgPath, pkgName, "man",
                           paste(pkgName, "QC.Rd", sep = ""))
    write(paste("\\name{", pkgName, "QC}\n",
                "\\alias{", pkgName, "QC}\n",
                "\\title{", "Quality control information for ",
                pkgName, "}\n",
                "\\description{\n A data file containing statistics ",
                "for all the data files in this package. The data ",
                "can be used for quality control purpose\n}\n",
                "\\details{\n", paste("This file contains quality control ",
                            "information that can be displayed by ",
                            "typing ", pkgName, "() after loading ",
                            "the package using library(", pkgName,
                            "). The follow items are included:\n\n",
                            "Date built - Date when the package was built.",
                            "\n\nNumber of probes - total number of ",
                            "probes included\n\n", "Probe number ",
                            "missmatch - if the total number of probes",
                            " of any of the data file is different ",
                            "from a base file used to check the data files",
                            " the name of the data file will be listed\n\n",
                            "Probe missmatch - if any of probes in a data",
                            " file missmatched that of the base file, ",
                            " the name of the data file will be listed\n\n",
                            " Mappings found for probe based files - ",
                            " number of mappings obtained for the total ",
                            "number of probes\n\n", "Mappings found for ",
                            "non-probe based files - total number of ",
                            "mappings obtained", sep = ""), "\n}\n",
                "\\keyword{datasets}\n", sep = ""), filename)
}

# Get build information for yeast genome source data
getBuild4Yeast <- function(src, manName){
    if(is.element(manName, c("GENENAME", "PMID", "GO", "ORF", "CHR",
                             "CHRLOC", "DESCRIPTION", "CHRLENGTHS",
                             "GO2PROBE", "GO2ALLPROBES", "ALIAS"))){
        if(manName != "DESCRIPTION"){
            probeDesc <- " PROBE ids are Open Reading Frame (ORF) ids."
        }else{
            probeDesc <- ""
        }
        return(paste("\\details{\n", "Mappings were based on data ",
                     "provided by Yeast Genome project.", probeDesc, "\n\n",
                     paste(paste("Source data built:",
                     "Yeast Genome data are built at various time ",
                     "intervals. Sources used were downloaded ",
                     date(), "\n",
                     paste("Package built:", date()), sep = "")), "\n}\n",
                     "\\references{\n", paste("\\url{", getYGUrl(), "}",
                                              sep = ""), "\n}\n", sep = ""))
    }else{
        return(getSrcBuiltNRef(src))
    }
}

==> AnnBuilder_1.4.2.tar.gz: AnnBuilder/R/writeManPage.R <==
# This function writes all the elements other than rda files required
# for a data package
writeAccessory <- function(pkgName, pkgPath, organism, version,
                         author = list(author = "who",
                         maintainer = "who@email.net"),
                         dataSrc = "various public data repositories",
                         license = "LGPL"){
    # Write to DESCRIPTION
    writeDescription(pkgName, pkgPath, version, author, dataSrc, license)
    # Write Rd files for all the rda files that already exist in data
    for(i in getAllRdaName(pkgName, pkgPath)){
        writeManPage(pkgName, pkgPath, i, organism,
                     src = get(i, AnnInfo)$src)
    }
    # Write a function that displays data information when called
    # using pkgName() and the man page for the function
    writeFun (pkgPath, pkgName, organism = organism)
    writeMan4Fun(pkgName, pkgPath, organism)
    # Write .First.lib
    writeZZZ(pkgPath, pkgName)
    # Put the pretty print function for QC data and man page in
#    putPrettyPrint(pkgName, pkgPath)
}

# Functions that write the documentation files for a data package.
#
# Copyright 2002, J. Zhang, all rights reserved.
#

writeManPage <- function(pkgName, pkgPath, manName, organism = "human",
                         src = "ll", isEnv = TRUE){

    path <- file.path(pkgPath, pkgName, "man")
    filename <- file.path(path, paste(pkgName, formatName(manName),
                                    ".Rd", sep = ""))
    if(is.na(src)){
        srcBuild <- "N/A"
    }else{
        if(toupper(organism) == "YEAST"){
            srcBuild <- getBuild4Yeast(src, manName)
        }else{
            srcBuild <- getSrcBuiltNRef(src, organism)
        }
    }
    write(paste("\\name{", paste(pkgName, manName, sep = ""), "}\n",
                "\\alias{", paste(pkgName, manName, sep = ""), "}\n",
                "\\title{", "An annotation data file for ", manName,
                " in the ", pkgName, " package}\n",
                "\\description{\n", get(manName, AnnInfo)$long, "\n}\n",
                srcBuild, getExample(pkgName, manName, isEnv),
                "\\keyword{datasets}\n", sep = ""), filename)
}

getExample <- function(pkgName, manName, isEnv = TRUE){
    if(isEnv){
        return(paste("\\examples{\n", paste("\trequire(\"annotate\")",
                                            "|| stop(\"annotate",
                                            "unavailable\")\n"),
                     paste(paste("\txx <- ls(env = ",
                           paste(pkgName, formatName(manName), sep = ""),
                           ")", sep = ""),
                           "\tif(length(xx) > 0){",
                           "\t\t# Using get for value of the first key",
                           paste("\t\tget(xx[1],", paste(pkgName,
                              formatName(manName), sep = ""), ")"),
                           "\t\t#Using multiget for a few keys",
                           "\t\tif(length(xx) >= 3){",
                           paste("\t\t\tmultiget(xx[1:3],", paste(pkgName,
                              formatName(manName), sep = ""), ")"),
                           "\t\t\t#Using lookUp of annotate(> 1.3.4)",
                           paste("\t\t\tlookUp(xx[1:3],\"", pkgName, "\",\"",
                                 manName, "\")", sep = ""), "\t\t}",
                           sep = "\n"),
                           "\n\t}\n}\n", sep = ""))
    }else{
        return(paste("\\examples{\n",
               paste("length(", pkgName, manName, ")", sep = ""),
                     "\n}\n", sep = ""))
    }
}

getSrcBuiltNRef <- function(src, organism){
    switch(toupper(src),
           "LL" = dataSource <- "LocusLink",
           "UG" = dataSource <- "UniGene",
           "KEGG" = dataSource <- "KEGG",
           "GO" = dataSource <- "Gene Ontology",
           "GP" = dataSource <- "Human Genome Project",
           "YG" = dataSource <- "Yeast Genome Project",
           "HG" = dataSource <- "HomoloGene",
           "REFSEQ" = dataSource <- "Reference Sequence Project",
           dataSource <- src)

    if(src == ""){
        return(paste("\\details{\n",
               paste(paste("Package built:", date())), "\n}\n", sep = ""))
    }else{
        return(paste("\\details{\n", paste("Mappings were based on data ",
                                           "provided by ", dataSource,
                                           "\n\n", sep = ""),
                     paste(paste("Source data built:",
                                 getSrcNBuilt(src, organism), "\n",
                                 paste("Package built:", date()),
                                 sep = "")), "\n}\n",
                     "\\references{\n", paste("\\url{", getSrcUrl(src), "}",
                                              sep = ""), "\n}\n", sep = ""))
    }
}

# This function writes the man page for the function that displays
# data information when invoked by typing pkgName()
writeMan4Fun <- function(pkgName, pkgPath, organism = "human", QCList,
                         dSrc = "all"){
    fileName <- file.path(pkgPath, pkgName, "man",
                          paste(pkgName, ".Rd", sep = ""))
    if(dSrc == "all"){
        dSrc <- getDSrc(organism)
    }
    item <- getSrcNBuilt(dSrc, organism)
    item <- paste(item, sep = "\n")
    write(paste("\\name{", pkgName, "}\n",
                "\\alias{", pkgName, "}\n",
                "\\title{",
                "Genomic Annotation data package built with AnnBuilder}\n",
                "\\description{\nThe package is built using a ",
                "downloadable R package - AnnBuilder (download and build ",
                "your own) from www.bioconductor.org using the ",
                "following public data sources:\n", item,
                "\n\nThe function ", pkgName, "() provides ",
                "information about the binary data files}\n",
                "\\keyword{datasets}\n", sep = ""), fileName)

}

escapeLatexChr <- function(item){
    item <- gsub("_", "\\\\_", item)
    item <- gsub("#", "\\\\#", item)
    item <- gsub("&", "\\\\&", item)
    item <- gsub("%", "\\\\%", item)
    item <- gsub("{", "\\\\{", item)
    item <- gsub("}", "\\\\}", item)
    return(item)
}

getSrcNBuilt <- function(dSrc, organism){
    items <- ""
    for(i in dSrc){
        switch(toupper(i),
               "LL" = toAdd <- paste("LocusLink",
                                      getUrlNBuilt("LL", organism)),
               "GP" = toAdd <- paste("Human Genome Project",
                                 getUrlNBuilt("GP", organism)),
               "UG" = toAdd <- paste("UniGene",
                                      getUrlNBuilt("UG", organism)),
               "GO" = toAdd <- paste("Gene Ontology Consortium",
                                      getUrlNBuilt("GO", organism)),
               "KEGG" = toAdd <- paste("KEGG",
                                      getUrlNBuilt("KEGG", organism)),
               "YG" = toAdd <- paste("Yeast Genome",
                                      getUrlNBuilt("YG", organism)),
               "HG" = toAdd <- paste("Homology",
                                      getUrlNBuilt("HG"), organism),
               "REFSEQ" = toAdd <- paste("Reference Sequence project",
                                      getUrlNBuilt("REFSEQ", organism),
                                      organism),
               warning(paste("Source", i, "is not a valid name!")))
        items <- paste(items, "\n", toAdd, sep = "")
    }
    return(items)
}

getUrlNBuilt <- function(src, organism){
    paste("built: ", escapeLatexChr(getSrcBuilt(src, organism)), ".",
          "\\url{", escapeLatexChr(getSrcUrl(src, organism)), "}.", sep = "")
}

#getItem <- function(name, content){
#    paste("\\item{", name, "}{",content, "}", sep = "")
#}

formatName <- function (toFormat){
    gsub("*(_)*", "", toFormat)
}

writeREADME <- function(pkgPath, pkgName, urls){

    OPENING <- paste("The binary data files in this package were constructed",
                     "using data from the following sources identified",
                     "by their URLs:")
    CLOSING <- paste("We highly appreciate their efforts of making",
                     "the data available publically")


    fileName <- file.path(pkgPath, pkgName, "README")

    write(OPENING, file = fileName, append = FALSE)
    for(i in urls)
        write(i, file = fileName, append = TRUE)
    write(CLOSING, file = fileName, append = TRUE)
}

#writeIndex <- function(path, pkgname){
#    indexPath <- file.path(path, pkgname)
#    system(paste("cd", indexPath))
#    system("R CMD Rdindex man >INDEX")
#    system(paste("cd", getwd()))
#}

writeDescription <- function(pkgName, pkgPath, version, author,
                             dataSrc = "various public data repositories",
                             license = "LGPL"){

    path <- file.path(pkgPath, pkgName)
    fileName <- file.path(path, "DESCRIPTION")
    if(file.exists(fileName)){
        unlink(fileName)
    }

    write(paste("Package:", pkgName,
                "\nTitle: A data package containing",
                "annotation data for", pkgName,
                "\nVersion:", version,
                "\nCreated:", date(),
                "\nAuthor:", author[["author"]],
                "\nDescription: Annotation data file for",
                pkgName, "assembled using data\n   from",
                dataSrc,
                "\nMaintainer:", author[["author"]], "<",
                author[["maintainer"]], ">",
                "\nDepends: R(>= 1.9.0)",
                "\nLicense:", license, "\n"), file = fileName, append = FALSE)
}


getDSrc <- function(organism){
    switch(tolower(organism),
           "human" = ,
           "rat" = ,
           "mouse" = return(c("LL", "GO", "KEGG", "GP", "UG")),
           "yeast" = return(c("KEGG", "GO", "YG")),
           "kegg" = return("KEGG"),
           "go" = return("GO"),
           "hg" = return("HG"),
           stop(paste("Organism", organism, "not supported!")))
}

# This function searches the package to be built for names of the rda
# files already created
getAllRdaName <- function(pkgName, pkgPath){
    rdaNames <- gsub(".rda", "",
                     list.files(file.path(pkgPath, pkgName, "data")))
    rdaNames <- sub(pkgName, "", rdaNames)
    return(rdaNames[!is.element(rdaNames, c("QC", "print.ABQCList"))])
}

writeFun <- function (pkgPath, pkgName, organism = "human"){
    fileName <- file.path(pkgPath, pkgName, "R",
                          paste(pkgName, ".R", sep = ""))

    toWrite <- paste(pkgName, " <- function(){\n",
                     "load(file.path(.path.package(\"", pkgName, "\"), ",
                     "\"data\", \"", paste(pkgName, "QC.rda", sep = ""),
                     "\"))\ncat(", paste(pkgName, "QC", sep = ""),
                     ")}", sep = "")

   write(toWrite, file = fileName)
}

writeZZZ <- function(pkgPath, pkgName){
    fileName <- file.path(pkgPath, pkgName, "R", "zzz.R")
    copySubstitute(file.path(.path.package("AnnBuilder"), "scripts",
                             "dataPkgLoad.R"), fileName,
                   list(PACKAGE = pkgName))
}

#putPrettyPrint <- function(pkgName, pkgPath){
#    path <- file.path(.path.package("AnnBuilder"))
#    dump("print.ABQCList", file = file.path(pkgPath, pkgName, "R",
#                           "print.ABQCList.R"))
#    manPage <- readLines(file.path(path, "data", "print.ABQCList.Rd"))
#    write(manPage, file = file.path(pkgPath, pkgName, "man",
#    "print.ABQCList.Rd"))
#}


#getText4Desc <- function(pkgName, manName){
    # This is not used but still kept here
#    description <- paste("This is an R rda file (a external ",
#                         "representation of R objects that canbe ",
#                         "read back from at a later date by using ",
#                         "the function `load' (or `data' in some ",
#                         "cases)) that contains an R environment ",
#                         "object with key-value paris. For a ",
#                         "given key, the value is a vector with a ",
#                         "single or multiple elements depending ",
#                             "on whether the key can be mapped to ",
#                         "only one or a group of values",
#                         "\n\nAll the funcitons that can be ",
#                         "applied to an R environment is ",
#                         "applicable to the data file. For ",
#                         "example, ls(", paste(pkgName, manName,
#                                               sep = ""), ") ",
#                         "returns a vector containing all the ",
#                             "keys and get(", "keyvalue", "env = ",
#                         paste(pkgName, manName, sep = ""),
#                         " returns a vector containg the ",
#                         "value(s) corresponding to the key ",
#                         "(keyvalue). multiget(c(\"key1\", ",
#                         "\"key2\", ..., \"keyX\"), env = ",
#                         paste(pkgName, manName, sep = ""),
#                             ") returns a list with the ",
#                         "corresponding values as elements.", sep = "")
#    return()
#}

writeMan4QC <- function(pkgName, pkgPath){

    path <- file.path(pkgPath, pkgName, "man")
    filename <- file.path(pkgPath, pkgName, "man",
                           paste(pkgName, "QC.Rd", sep = ""))
    write(paste("\\name{", pkgName, "QC}\n",
                "\\alias{", pkgName, "QC}\n",
                "\\title{", "Quality control information for ",
                pkgName, "}\n",
                "\\description{\n A data file containing statistics ",
                "for all the data files in this package. The data ",
                "can be used for quality control purpose\n}\n",
                "\\details{\n", paste("This file contains quality control ",
                            "information that can be displayed by ",
                            "typing ", pkgName, "() after loading ",
                            "the package using library(", pkgName,
                            "). The follow items are included:\n\n",
                            "Date built - Date when the package was built.",
                            "\n\nNumber of probes - total number of ",
                            "probes included\n\n", "Probe number ",
                            "missmatch - if the total number of probes",
                            " of any of the data file is different ",
                            "from a base file used to check the data files",
                            " the name of the data file will be listed\n\n",
                            "Probe missmatch - if any of probes in a data",
                            " file missmatched that of the base file, ",
                            " the name of the data file will be listed\n\n",
                            " Mappings found for probe based files - ",
                            " number of mappings obtained for the total ",
                            "number of probes\n\n", "Mappings found for ",
                            "non-probe based files - total number of ",
                            "mappings obtained", sep = ""), "\n}\n",
                "\\keyword{datasets}\n", sep = ""), filename)
}

# Get build information for yeast genome source data
getBuild4Yeast <- function(src, manName){
    if(is.element(manName, c("GENENAME", "PMID", "GO", "ORF", "CHR",
                             "CHRLOC", "DESCRIPTION", "CHRLENGTHS",
                             "GO2PROBE", "GO2ALLPROBES", "ALIAS",
                             "#CHROMSEQ#"))){
        if(!any(manName == c("DESCRIPTION", "#CHROMSEQ#"))){
            probeDesc <- " PROBE ids are Open Reading Frame (ORF) ids."
        }else{
            probeDesc <- ""
        }
        return(paste("\\details{\n", "Annotation based on data ",
                     "provided by Yeast Genome project.", probeDesc, "\n\n",
                     paste(paste("Source data built:",
                     "Yeast Genome data are built at various time ",
                     "intervals. Sources used were downloaded ",
                     date(), "\n",
                     paste("Package built:", date()), sep = "")), "\n}\n",
                     "\\references{\n", paste("\\url{", getYGUrl(), "}",
                                              sep = ""), "\n}\n", sep = ""))
    }else{
        return(getSrcBuiltNRef(src, "YG"))
    }
}
